nrf-pac

Crates

0.4.0

Versions

nrf52810

Flavors

Radio

Struct Radio 

pub struct Radio { /* private fields */ }
2.4 GHz Radio.

Implementations

Source

impl Radio

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn tasks_txen(self) -> Reg<u32, W>

Enable RADIO in TX mode.

pub const fn tasks_rxen(self) -> Reg<u32, W>

Enable RADIO in RX mode.

pub const fn tasks_start(self) -> Reg<u32, W>

Start RADIO.

pub const fn tasks_stop(self) -> Reg<u32, W>

Stop RADIO.

pub const fn tasks_disable(self) -> Reg<u32, W>

Disable RADIO.

pub const fn tasks_rssistart(self) -> Reg<u32, W>

Start the RSSI and take one single sample of the receive signal strength.

pub const fn tasks_rssistop(self) -> Reg<u32, W>

Stop the RSSI measurement.

pub const fn tasks_bcstart(self) -> Reg<u32, W>

Start the bit counter.

pub const fn tasks_bcstop(self) -> Reg<u32, W>

Stop the bit counter.

pub const fn events_ready(self) -> Reg<u32, RW>

RADIO has ramped up and is ready to be started.

pub const fn events_address(self) -> Reg<u32, RW>

Address sent or received.

pub const fn events_payload(self) -> Reg<u32, RW>

Packet payload sent or received.

pub const fn events_end(self) -> Reg<u32, RW>

Packet sent or received.

pub const fn events_disabled(self) -> Reg<u32, RW>

RADIO has been disabled.

pub const fn events_devmatch(self) -> Reg<u32, RW>

A device address match occurred on the last received packet.

pub const fn events_devmiss(self) -> Reg<u32, RW>

No device address match occurred on the last received packet.

pub const fn events_rssiend(self) -> Reg<u32, RW>

Sampling of receive signal strength complete.

pub const fn events_bcmatch(self) -> Reg<u32, RW>

Bit counter reached bit count value.

pub const fn events_crcok(self) -> Reg<u32, RW>

Packet received with CRC ok.

pub const fn events_crcerror(self) -> Reg<u32, RW>

Packet received with CRC error.

pub const fn shorts(self) -> Reg<Shorts, RW>

Shortcuts between local events and tasks.

pub const fn intenset(self) -> Reg<Int, RW>

Enable interrupt.

pub const fn intenclr(self) -> Reg<Int, RW>

Disable interrupt.

pub const fn crcstatus(self) -> Reg<Crcstatus, R>

CRC status.

pub const fn rxmatch(self) -> Reg<Rxmatch, R>

Received address.

pub const fn rxcrc(self) -> Reg<Rxcrc, R>

CRC field of previously received packet.

pub const fn dai(self) -> Reg<Dai, R>

Device address match index.

pub const fn packetptr(self) -> Reg<u32, RW>

Packet pointer.

pub const fn frequency(self) -> Reg<Frequency, RW>

Frequency.

pub const fn txpower(self) -> Reg<Txpower, RW>

Output power.

pub const fn mode(self) -> Reg<Mode, RW>

Data rate and modulation.

pub const fn pcnf0(self) -> Reg<Pcnf0, RW>

Packet configuration register 0.

pub const fn pcnf1(self) -> Reg<Pcnf1, RW>

Packet configuration register 1.

pub const fn base0(self) -> Reg<u32, RW>

Base address 0.

pub const fn base1(self) -> Reg<u32, RW>

Base address 1.

pub const fn prefix0(self) -> Reg<Prefix0, RW>

Prefixes bytes for logical addresses 0-3.

pub const fn prefix1(self) -> Reg<Prefix1, RW>

Prefixes bytes for logical addresses 4-7.

pub const fn txaddress(self) -> Reg<Txaddress, RW>

Transmit address select.

pub const fn rxaddresses(self) -> Reg<Rxaddresses, RW>

Receive address select.

pub const fn crccnf(self) -> Reg<Crccnf, RW>

CRC configuration.

pub const fn crcpoly(self) -> Reg<Crcpoly, RW>

CRC polynomial.

pub const fn crcinit(self) -> Reg<Crcinit, RW>

CRC initial value.

pub const fn tifs(self) -> Reg<Tifs, RW>

Inter Frame Spacing in us.

pub const fn rssisample(self) -> Reg<Rssisample, R>

RSSI sample.

pub const fn state(self) -> Reg<State, R>

Current radio state.

pub const fn datawhiteiv(self) -> Reg<Datawhiteiv, RW>

Data whitening initial value.

pub const fn bcc(self) -> Reg<u32, RW>

Bit counter compare.

pub const fn dab(self, n: usize) -> Reg<u32, RW>

Description collection: Device address base segment n.

pub const fn dap(self, n: usize) -> Reg<Dap, RW>

Description collection: Device address prefix n.

pub const fn dacnf(self) -> Reg<Dacnf, RW>

Device address match configuration.

pub const fn modecnf0(self) -> Reg<Modecnf0, RW>

Radio mode configuration register 0.

pub const fn power(self) -> Reg<Power, RW>

Peripheral power control.